@@ -5,21 +5,12 @@ import autolens.plot as aplt
 """
 This script simulates `Imaging` of a strong lens where:
 
- - The lens `Galaxy`'s `MassProfile` is a *SphericalIsothermal*.
+ - The lens total mass distribution is a *SphericalIsothermal*.
  - The source `Galaxy`'s `LightProfile` is a *SphericalExponential*.
 
 This dataset is used in chapter 2, tutorials 1-3.
 """
 
-# %%
-"""Use the WORKSPACE environment variable to determine the path to the `autolens_workspace`."""
-
-# %%
-import os
-
-workspace_path = os.environ["WORKSPACE"]
-print("Workspace Path: ", workspace_path)
-
 """
 The `dataset_type` describes the type of data being simulated (in this case, `Imaging` data) and `dataset_name` 
 gives it a descriptive name. They define the folder the dataset is output to on your hard-disk:
@@ -32,10 +23,10 @@ dataset_type = "chapter_4"
 dataset_name = "mass_sie__source_sersic_x5"
 
 """
-Create the path where the dataset will be output, which in this case is:
+Returns the path where the dataset will be output, which in this case is:
 `/autolens_workspace/howtolens/dataset/chapter_2/lens_sis__source_sersic_x5/`
 """
-dataset_path = f"{workspace_path}/howtolens/dataset/{dataset_type}/{dataset_name}"
+dataset_path = f"dataset/howtolens/{dataset_type}/{dataset_name}"
 
 """
 For simulating an image of a strong lens, we recommend using a GridIterate object. This represents a grid of $(y,x)$ 
@@ -59,14 +50,11 @@ psf = al.Kernel.from_gaussian(
 )
 
 """
-To simulate the `Imaging` dataset we first create a simulator, which defines the expoosure time, background sky,
+To simulate the `Imaging` dataset we first create a simulator, which defines the exposure time, background sky,
 noise levels and psf of the dataset that is simulated.
 """
 simulator = al.SimulatorImaging(
-    exposure_time_map=al.Array.full(fill_value=300.0, shape_2d=grid.shape_2d),
-    psf=psf,
-    background_sky_map=al.Array.full(fill_value=0.1, shape_2d=grid.shape_2d),
-    add_noise=True,
+    exposure_time=300.0, psf=psf, background_sky_level=0.1, add_poisson_noise=True
 )
 
 """
@@ -90,7 +78,7 @@ lens_galaxy = al.Galaxy(
 
 source_galaxy_0 = al.Galaxy(
     redshift=1.0,
-    sersic=al.lp.EllipticalSersic(
+    bulge=al.lp.EllipticalSersic(
         centre=(0.1, 0.1),
         elliptical_comps=(0.1, 0.0),
         intensity=0.2,
@@ -101,7 +89,7 @@ source_galaxy_0 = al.Galaxy(
 
 source_galaxy_1 = al.Galaxy(
     redshift=1.0,
-    sersic=al.lp.EllipticalSersic(
+    bulge=al.lp.EllipticalSersic(
         centre=(-0.25, 0.25),
         elliptical_comps=(0.0, 0.15),
         intensity=0.1,
@@ -112,7 +100,7 @@ source_galaxy_1 = al.Galaxy(
 
 source_galaxy_2 = al.Galaxy(
     redshift=1.0,
-    sersic=al.lp.EllipticalSersic(
+    bulge=al.lp.EllipticalSersic(
         centre=(0.45, -0.35),
         elliptical_comps=(0.0, 0.222222),
         intensity=0.03,
@@ -123,7 +111,7 @@ source_galaxy_2 = al.Galaxy(
 
 source_galaxy_3 = al.Galaxy(
     redshift=1.0,
-    sersic=al.lp.EllipticalSersic(
+    bulge=al.lp.EllipticalSersic(
         centre=(-0.05, -0.0),
         elliptical_comps=(0.05, 0.1),
         intensity=0.03,
@@ -134,7 +122,7 @@ source_galaxy_3 = al.Galaxy(
 
 source_galaxy_4 = al.Galaxy(
     redshift=1.0,
-    sersic=al.lp.EllipticalSersic(
+    bulge=al.lp.EllipticalSersic(
         centre=(0.85, -0.85),
         elliptical_comps=(0.0, 0.222222),
         intensity=0.03,
@@ -145,7 +133,7 @@ source_galaxy_4 = al.Galaxy(
 
 source_galaxy_5 = al.Galaxy(
     redshift=1.0,
-    sersic=al.lp.EllipticalSersic(
+    bulge=al.lp.EllipticalSersic(
         centre=(-0.75, -0.1),
         elliptical_comps=(0.05, 0.1),
         intensity=0.03,
