@@ -4,14 +4,14 @@ from test_autolens.integration.tests.imaging import runner
 
 test_type = "lens__source"
 test_name = "lens_mass__source_x2__hyper"
-data_name = "lens_sie__source_smooth"
+dataset_name = "lens_sie__source_smooth"
 instrument = "vro"
 
 
 def make_pipeline(name, path_prefix, search=af.DynestyStatic()):
 
     phase1 = al.PhaseImaging(
-        phase_name="phase_1",
+        name="phase[1]",
         path_prefix=path_prefix,
         galaxies=dict(
             lens=al.GalaxyModel(redshift=0.5, mass=al.mp.EllipticalIsothermal),
@@ -21,7 +21,7 @@ def make_pipeline(name, path_prefix, search=af.DynestyStatic()):
     )
 
     phase2 = al.PhaseImaging(
-        phase_name="phase_2",
+        name="phase[2]",
         path_prefix=path_prefix,
         galaxies=dict(
             lens=al.GalaxyModel(
@@ -49,7 +49,7 @@ def make_pipeline(name, path_prefix, search=af.DynestyStatic()):
             )
 
     phase3 = HyperLensSourcePlanePhase(
-        phase_name="phase_3",
+        name="phase[3]",
         path_prefix=path_prefix,
         galaxies=dict(
             lens=al.GalaxyModel(
@@ -69,7 +69,7 @@ def make_pipeline(name, path_prefix, search=af.DynestyStatic()):
         search=search,
     )
 
-    return al.PipelineDataset(name, phase1, phase2, phase3)
+    return al.PipelineDataset(name, path_prefix, phase1, phase2, phase3)
 
 
 if __name__ == "__main__":
