@@ -4,7 +4,7 @@ from test_autolens.integration.tests.imaging import runner
 
 test_type = "lens__source_inversion"
 test_name = "lens_both__source_rectangular"
-data_name = "lens_bulge__source_smooth"
+dataset_name = "lens_bulge__source_smooth"
 instrument = "vro"
 
 
@@ -22,7 +22,7 @@ def make_pipeline(name, path_prefix, search=af.DynestyStatic()):
     pixelization.shape_1 = 20.0
 
     phase1 = al.PhaseImaging(
-        phase_name="phase_1",
+        name="phase[1]",
         path_prefix=path_prefix,
         galaxies=dict(
             lens=al.GalaxyModel(
@@ -39,7 +39,7 @@ def make_pipeline(name, path_prefix, search=af.DynestyStatic()):
     phase1.search.n_live_points = 60
     phase1.search.facc = 0.8
 
-    return al.PipelineDataset(name, phase1)
+    return al.PipelineDataset(name, path_prefix, phase1)
 
 
 if __name__ == "__main__":
