@@ -13,10 +13,10 @@ def run(
     test_path = "{}/../..".format(os.path.dirname(os.path.realpath(__file__)))
     output_path = f"{test_path}/output/imaging"
     config_path = f"{test_path}/{config_folder}"
-    conf.instance = conf.Config(config_path=config_path, output_path=output_path)
+    conf.instance.push(config_path, output_path=output_path)
 
     imaging = instrument_util.load_test_imaging(
-        data_name=module.dataset_name, instrument=module.instrument
+        dataset_name=module.dataset_name, instrument=module.instrument
     )
 
     if mask is None:
@@ -27,7 +27,7 @@ def run(
     info = {"Test": 100}
 
     module.make_pipeline(
-        name=test_name, path_prefix=[module.test_type, test_name], search=search
+        name=test_name, path_prefix=f"{module.test_type}/{test_name}", search=search
     ).run(dataset=imaging, mask=mask, info=info)
 
 
